==> mesa-22.0.4.tar.xz: mesa-22.0.4/src/gallium/drivers/nouveau/codegen/lib/gk110.asm.h <==
uint64_t gk110_builtin_code[] = {
/* 0x0000: gk110_div_u32 */
	0x08a0a0a010a010a0,
	0xe1800000009c000a,
	0x220000000f9c0808,
	0x74000000009fc00e,
	0xe2400000011c0c0a,
	0xe6010000009c2806,
	0xe1c00000011c040e,
	0xd2000800019c080a,
	0x08a0a0a0a0a0a0a0,
	0xe1c00000011c040e,
	0xd2000800019c080a,
	0xe1c00000011c040e,
	0xd2000800019c080a,
	0xe1c00000011c040e,
	0xd2000800019c080a,
	0xe1c00000011c040e,
	0x0810b0a0a010a010,
	0xd2000800019c080a,
	0xe4c03c00001c000e,
	0xe1c00400011c0002,
	0xe6010000009c280a,
	0xd0000c00001c0406,
	0xdb601c00011c041e,
	0xe088000001000406,
	0x0880a0b88010b0a0,
	0x4000000000800001,
	0xdb601c000100041e,
	0xe088000001000406,
	0x4000000000800001,
	0x19000000001c003c,
/* 0x00f0: gk110_div_s32 */
	0xdb181c007f9c005e,
	0xdb1a08007f9c047e,
	0x08a010a010a0a080,
	0xe6100000001ce802,
	0xe6100000009ce806,
	0xe1800000009c000a,
	0x220000000f9c0808,
	0x74000000009fc00e,
	0xe2400000011c0c0a,
	0xe6010000009c2806,
	0x08a0a0a0a0a0a0a0,
	0xe1c00000011c040e,
	0xd2000800019c080a,
	0xe1c00000011c040e,
	0xd2000800019c080a,
	0xe1c00000011c040e,
	0xd2000800019c080a,
	0xe1c00000011c040e,
	0x08a0a010a010a0a0,
	0xd2000800019c080a,
	0xe1c00000011c040e,
	0xd2000800019c080a,
	0xe4c03c00001c000e,
	0xe1c00400011c0002,
	0xe6010000009c280a,
	0xd0000c00001c0406,
	0x0880a010b0a010b0,
	0xdb601c00011c041e,
	0xe088000001000406,
	0x4000000000800001,
	0xdb601c000100041e,
	0xe088000001000406,
	0x4000000000800001,
	0xe6010000000ce802,
	0x08a0a0a010a0b810,
	0xe60100000088e806,
	0x19000000001c003c,
/* 0x0218: gk110_rcp_f64 */
	0xc00000058a1c0409,
	0x407fffffff9c080d,
	0x1480000050000000,
	0xb3401c03fe9c0c1d,
	0xe4c03c007f9c000e,
	0x08a0a0bcacb410bc,
	0x8580000000603c02,
	0x747fffffff9fc00e,
	0xb4601fff801c021d,
	0x120000000420003c,
	0x21000400005c0404,
/* 0x0270: rcp_inf_or_denorm_or_zero */
	0x203ff800001c0410,
	0xb3281c00001c101d,
	0x0880bcacb4bc10ac,
	0x120000000800003c,
	0x223ff800001c0404,
	0xe4c03c007fdc0002,
/* 0x02a0: rcp_denorm_or_zero */
	0xb4601c00001c021d,
	0x120000000400003c,
	0x213ff800005c0404,
/* 0x02b8: rcp_denorm */
	0xc400021a801c0001,
	0x08a010a0a0aca0bc,
	0x740000001b5fc00e,
/* 0x02d0: rcp_rejoin */
	0xb3181c00001c0c1d,
	0x12000000c000003c,
	0xc00000058a1c0409,
	0x204007ffff9c041c,
	0x401ff800001c1c1d,
	0xe4c03c00001c001a,
	0x08b8aca8a0a010ac,
	0xe5400c00031c3816,
	0x84000000021c1412,
	0x745fc000001fc002,
	0xcc000000029c1016,
	0xcc081000029c1002,
	0xe5400000001c2c02,
	0xe5410000031c3c1a,
	0x08a4a4a4a4a4a4b8,
	0xc54001fc001c2c21,
	0xdb802000001c1812,
	0xdb800000021c0002,
	0xdb802000001c1812,
	0xdb800000021c0002,
	0xdb802000001c1812,
	0xdb800000021c0002,
	0x08a0a0a0a0a080a4,
	0xdb802000001c1812,
	0xdb800000021c0002,
	0x48000001ff9c0809,
	0xe0800000019c0812,
	0xc00000058a1c040d,
	0xe0800000021c0c0e,
	0x407fffffff9c0c09,
	0x08aca0a0aca0aca0,
	0xb3101c03ff1c081d,
	0x120000000c20003c,
	0xc24000000a1c1011,
	0xe0800000009c1006,
	0x12000000381c003c,
/* 0x03f0: rcp_result_inf_or_denorm */
	0xb3681c03ff9c0c1d,
	0x120000001420003c,
	0x08bc948caca09480,
	0x20400000001c0404,
	0xe4c03c007f9c0002,
	0x403ff800001c0405,
	0x120000001c1c003c,
/* 0x0428: rcp_result_denorm */
	0xb3501c00001c0c1d,
	0x204007ffff9c0404,
	0xc54001f400002c19,
	0x089c80a8b8b0a0bc,
	0xc54001f800202c19,
	0x40000800001c0405,
	0xe4000000031c0002,
/* 0x0460: rcp_end */
	0x19000000001c003c,
/* 0x0468: gk110_rsq_f64 */
	0xb4601fff801c021d,
	0x2100040000000404,
	0x203fffffff9c0408,
	0x08a0a094b0a0809c,
	0xc00000058a1c040d,
	0xb3301c00011c0c3d,
	0xe2001000011c000a,
	0xc400021a80040001,
	0x84000000039c0416,
	0xb2d01c03ff9c0c19,
	0xe2000000031c080a,
	0x08a0b8a09c80aca0,
	0xb3501c00001c081d,
	0x120000001000003c,
	0x20400000001c0404,
	0xe4c03c007f9c0002,
	0xe2001000029c0406,
	0x19000000001c003c,
/* 0x04f8: rsq_norm */
	0xe4c03c007f9c0012,
	0x08a4a4a4a4a4a4bc,
	0xc54001f8001c2c21,
	0xe4000000041c000a,
	0xe4000000021c0802,
	0xdb882000001c101a,
	0xdb801000031c1012,
	0xe4000000021c0802,
	0xdb882000001c101a,
	0x08a4a4a4a4a4a4a4,
	0xdb801000031c1012,
	0xe4000000021c0802,
	0xdb882000001c101a,
	0xdb801000031c1012,
	0xe4000000021c0802,
	0xdb882000001c101a,
	0xdb801000031c1012,
	0x08000000b8a080a4,
	0xc400020d00041011,
	0xe4c03c00029c0006,
	0xe4c03c00021c0002,
	0x19000000001c003c,
};

uint64_t gk110_builtin_offsets[] = {
	0x0000000000000000,
	0x00000000000000f0,
	0x0000000000000218,
	0x0000000000000468,
};

==> mesa_25.2.6.orig.tar.xz: mesa-25.2.6/src/gallium/drivers/nouveau/codegen/lib/gk110.asm.h <==
const uint64_t gk110_builtin_code[] = {
/* 0x0000: gk110_div_u32 */
	0x08a0a0a010a010a0,
	0xe1800000009c000a,
	0x220000000f9c0808,
	0x74000000009fc00e,
	0xe2400000011c0c0a,
	0xe6010000009c2806,
	0xe1c00000011c040e,
	0xd2000800019c080a,
	0x08a0a0a0a0a0a0a0,
	0xe1c00000011c040e,
	0xd2000800019c080a,
	0xe1c00000011c040e,
	0xd2000800019c080a,
	0xe1c00000011c040e,
	0xd2000800019c080a,
	0xe1c00000011c040e,
	0x0810b0a0a010a010,
	0xd2000800019c080a,
	0xe4c03c00001c000e,
	0xe1c00400011c0002,
	0xe6010000009c280a,
	0xd0000c00001c0406,
	0xdb601c00011c041e,
	0xe088000001000406,
	0x0880a0b88010b0a0,
	0x4000000000800001,
	0xdb601c000100041e,
	0xe088000001000406,
	0x4000000000800001,
	0x19000000001c003c,
/* 0x00f0: gk110_div_s32 */
	0xdb181c007f9c005e,
	0xdb1a08007f9c047e,
	0x08a010a010a0a080,
	0xe6100000001ce802,
	0xe6100000009ce806,
	0xe1800000009c000a,
	0x220000000f9c0808,
	0x74000000009fc00e,
	0xe2400000011c0c0a,
	0xe6010000009c2806,
	0x08a0a0a0a0a0a0a0,
	0xe1c00000011c040e,
	0xd2000800019c080a,
	0xe1c00000011c040e,
	0xd2000800019c080a,
	0xe1c00000011c040e,
	0xd2000800019c080a,
	0xe1c00000011c040e,
	0x08a0a010a010a0a0,
	0xd2000800019c080a,
	0xe1c00000011c040e,
	0xd2000800019c080a,
	0xe4c03c00001c000e,
	0xe1c00400011c0002,
	0xe6010000009c280a,
	0xd0000c00001c0406,
	0x0880a010b0a010b0,
	0xdb601c00011c041e,
	0xe088000001000406,
	0x4000000000800001,
	0xdb601c000100041e,
	0xe088000001000406,
	0x4000000000800001,
	0xe6010000000ce802,
	0x08a0a0a010a0b810,
	0xe60100000088e806,
	0x19000000001c003c,
/* 0x0218: gk110_rcp_f64 */
	0xc00000058a1c0409,
	0x407fffffff9c080d,
	0x1480000050000000,
	0xb3401c03fe9c0c1d,
	0xe4c03c007f9c000e,
	0x08a0a0bcacb410bc,
	0x8580000000603c02,
	0x747fffffff9fc00e,
	0xb4601fff801c021d,
	0x120000000420003c,
	0x21000400005c0404,
/* 0x0270: rcp_inf_or_denorm_or_zero */
	0x203ff800001c0410,
	0xb3281c00001c101d,
	0x0880bcacb4bc10ac,
	0x120000000800003c,
	0x223ff800001c0404,
	0xe4c03c007fdc0002,
/* 0x02a0: rcp_denorm_or_zero */
	0xb4601c00001c021d,
	0x120000000400003c,
	0x213ff800005c0404,
/* 0x02b8: rcp_denorm */
	0xc400021a801c0001,
	0x08a010a0a0aca0bc,
	0x740000001b5fc00e,
/* 0x02d0: rcp_rejoin */
	0xb3181c00001c0c1d,
	0x12000000c000003c,
	0xc00000058a1c0409,
	0x204007ffff9c041c,
	0x401ff800001c1c1d,
	0xe4c03c00001c001a,
	0x08b8aca8a0a010ac,
	0xe5400c00031c3816,
	0x84000000021c1412,
	0x745fc000001fc002,
	0xcc000000029c1016,
	0xcc081000029c1002,
	0xe5400000001c2c02,
	0xe5410000031c3c1a,
	0x08a4a4a4a4a4a4b8,
	0xc54001fc001c2c21,
	0xdb802000001c1812,
	0xdb800000021c0002,
	0xdb802000001c1812,
	0xdb800000021c0002,
	0xdb802000001c1812,
	0xdb800000021c0002,
	0x08a0a0a0a0a080a4,
	0xdb802000001c1812,
	0xdb800000021c0002,
	0x48000001ff9c0809,
	0xe0800000019c0812,
	0xc00000058a1c040d,
	0xe0800000021c0c0e,
	0x407fffffff9c0c09,
	0x08aca0a0aca0aca0,
	0xb3101c03ff1c081d,
	0x120000000c20003c,
	0xc24000000a1c1011,
	0xe0800000009c1006,
	0x12000000381c003c,
/* 0x03f0: rcp_result_inf_or_denorm */
	0xb3681c03ff9c0c1d,
	0x120000001420003c,
	0x08bc948caca09480,
	0x20400000001c0404,
	0xe4c03c007f9c0002,
	0x403ff800001c0405,
	0x120000001c1c003c,
/* 0x0428: rcp_result_denorm */
	0xb3501c00001c0c1d,
	0x204007ffff9c0404,
	0xc54001f400002c19,
	0x089c80a8b8b0a0bc,
	0xc54001f800202c19,
	0x40000800001c0405,
	0xe4000000031c0002,
/* 0x0460: rcp_end */
	0x19000000001c003c,
/* 0x0468: gk110_rsq_f64 */
	0xb4601fff801c021d,
	0x2100040000000404,
	0x203fffffff9c0408,
	0x08a0a094b0a0809c,
	0xc00000058a1c040d,
	0xb3301c00011c0c3d,
	0xe2001000011c000a,
	0xc400021a80040001,
	0x84000000039c0416,
	0xb2d01c03ff9c0c19,
	0xe2000000031c080a,
	0x08a0b8a09c80aca0,
	0xb3501c00001c081d,
	0x120000001000003c,
	0x20400000001c0404,
	0xe4c03c007f9c0002,
	0xe2001000029c0406,
	0x19000000001c003c,
/* 0x04f8: rsq_norm */
	0xe4c03c007f9c0012,
	0x08a4a4a4a4a4a4bc,
	0xc54001f8001c2c21,
	0xe4000000041c000a,
	0xe4000000021c0802,
	0xdb882000001c101a,
	0xdb801000031c1012,
	0xe4000000021c0802,
	0xdb882000001c101a,
	0x08a4a4a4a4a4a4a4,
	0xdb801000031c1012,
	0xe4000000021c0802,
	0xdb882000001c101a,
	0xdb801000031c1012,
	0xe4000000021c0802,
	0xdb882000001c101a,
	0xdb801000031c1012,
	0x08000000b8a080a4,
	0xc400020d00041011,
	0xe4c03c00029c0006,
	0xe4c03c00021c0002,
	0x19000000001c003c,
};

const uint64_t gk110_builtin_offsets[] = {
	0x0000000000000000,
	0x00000000000000f0,
	0x0000000000000218,
	0x0000000000000468,
};
